pub enum Error {
InvalidPadding,
InconsistentPart {
received: MessageDescription,
expected: MessageDescription,
},
InvalidPart,
NotEnoughSpace {
needed: usize,
capacity: usize,
},
TooManyFragments,
}Expand description
Errors that can happen during decoding.
Variants
InvalidPadding
The padding is invalid.
InconsistentPart
The received part is inconsistent with the previously received ones.
Fields

received: MessageDescriptionThe description of the message from the received part.

expected: MessageDescriptionThe expected description of the message originated from the previous parts scanned.
InvalidPart
The received part is empty.
NotEnoughSpace
Not enough space to receive the part.
TooManyFragments
Too many fragments.