MessageDescription

Struct MessageDescription 

pub struct MessageDescription {
    pub sequence_count: u32,
    pub message_length: usize,
    pub checksum: u32,
    pub fragment_length: usize,
}
Description of how a message is split into parts.

This structure is a subset of the information of a Part.

Fields

sequence_count: u32

The total sequence count.

message_length: usize

The total message length, in bytes, excluding the padding bytes size.

checksum: u32

The CRC32 checksum of the entire message.

fragment_length: usize

The length of a single fragment.