pub struct MessageDescription {
pub sequence_count: u32,
pub message_length: usize,
pub checksum: u32,
pub fragment_length: usize,
}Expand description
Description of how a message is split into parts.
This structure is a subset of the information of a Part.
Fields
sequence_count: u32The total sequence count.
message_length: usizeThe total message length, in bytes, excluding the padding bytes size.
checksum: u32The CRC32 checksum of the entire message.
fragment_length: usizeThe length of a single fragment.